stalker.core.models.Version — Stalker v0.1.1.a9 documentation

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »

# stalker.core.models.Version

class `stalker.core.models.` `Version`(tags=[], notes=[], **kwargs)

  Bases: `stalker.core.models.Entity`, `stalker.core.mixins.StatusMixin`

  The connection to the filesystem.

  A `Version` holds information about the incarnations of the files in the `Repository`. So if one creates a new version for a file or a sequences of file for a `Task` then the information is hold in the `Version` instance.

  Parameters: | take (str) – A short string holding the current take name. Can be any alphanumeric value (a-zA-Z0-0_) version (int) – An integer value showing the current version number. source_file (`Link`) – A `Link` instance, showing the source file of this version. outputs (list of `Link` instances) – A list of `Link` instances, holding the outputs of the current version. task (`Task`) – A `Task` instance showing the owner of this Version.

  `__init__`(tags=[], notes=[], **kwargs)

  Methods

  `__init__`(**kwargs[, tags, notes]) |

  Attributes

  `code` | The code name of this object.
  `created_by` | The `User` who has created this object.
  `date_created` | A `datetime.datetime` instance showing the creation date and time of this object.
  `date_updated` | A `datetime.datetime` instance showing the update date and time of this object.
  `description` | Description of this object.
  `name` | Name of this object
  `nice_name` | Nice name of this object.
  `notes` | All the notes about this entity.
  `status` | The current status index of the object.
  `status_list` | The list of statuses that this object can have.
  `tags` | A list of tags attached to this object.
  `type` | The type of the object.
  `updated_by` | The `User` who has updated this object.

  `code`

    The code name of this object.

    It accepts string or unicode values and any other kind of objects will be converted to string. In any update to the name attribute the code also will be updated. If the code is not initialized or given as None, it will be set to the uppercase version of the nice_name attribute. Setting the code attribute to None will reset it to the default value. The default value is the upper case form of the nice_name.

  `created_by`

    The `User` who has created this object.

  `date_created`

    A `datetime.datetime` instance showing the creation date and time of this object.

  `date_updated`

    A `datetime.datetime` instance showing the update date and time of this object.

  `description`

    Description of this object.

  `name`

    Name of this object

  `nice_name`

    Nice name of this object.

    It has the same value with the name (contextually) but with a different format like, all the white spaces replaced by underscores (“_”), all the CamelCase form will be expanded by underscore (_) characters and it is always lower case.

    There is also the `code` attribute which is simply the upper case form of `nice_name` if it is not defined differently (i.e set to another value).

  `notes`

    All the notes about this entity.

    It is a list of `Note` objects or an empty list, None will be converted to an empty list.

  `status`

    The current status index of the object.

    This is an integer value and shows the index of the `Status` object in the `StatusList` of this object.

  `status_list`

    The list of statuses that this object can have.

  `tags`

    A list of tags attached to this object.

    It is a list of `Tag` instances which shows the tags of this object

  `type`

    The type of the object.

    It is an instance of `Type` with a proper `target_entity_type`.

  `updated_by`

    The `User` who has updated this object.

### Navigation

- index
- next |
- previous |
- Stalker v0.1.1.a9 documentation »